Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/dataknobs_fsm/api/advanced.py | 544 | 427 | 0 | 22%
src/dataknobs_fsm/api/async_simple.py | 126 | 96 | 0 | 24%
src/dataknobs_fsm/api/simple.py | 125 | 99 | 0 | 21%
src/dataknobs_fsm/cli/commands.py | 0 | 0 | 0 | 100%
src/dataknobs_fsm/cli/main.py | 470 | 470 | 2 | 0%
src/dataknobs_fsm/config/builder.py | 299 | 268 | 0 | 10%
src/dataknobs_fsm/config/loader.py | 281 | 255 | 0 | 9%
src/dataknobs_fsm/config/schema.py | 172 | 54 | 0 | 69%
src/dataknobs_fsm/config/validator.py | 23 | 23 | 0 | 0%
src/dataknobs_fsm/core/arc.py | 206 | 160 | 2 | 22%
src/dataknobs_fsm/core/context_factory.py | 71 | 55 | 0 | 23%
src/dataknobs_fsm/core/data_modes.py | 103 | 55 | 42 | 47%
src/dataknobs_fsm/core/data_wrapper.py | 117 | 76 | 3 | 35%
src/dataknobs_fsm/core/exceptions.py | 40 | 6 | 0 | 85%
src/dataknobs_fsm/core/fsm.py | 248 | 210 | 3 | 15%
src/dataknobs_fsm/core/modes.py | 19 | 0 | 0 | 100%
src/dataknobs_fsm/core/network.py | 247 | 187 | 0 | 24%
src/dataknobs_fsm/core/result_formatter.py | 41 | 22 | 0 | 46%
src/dataknobs_fsm/core/state.py | 173 | 73 | 2 | 58%
src/dataknobs_fsm/core/transactions.py | 210 | 158 | 38 | 25%
src/dataknobs_fsm/execution/async_batch.py | 98 | 83 | 0 | 15%
src/dataknobs_fsm/execution/async_engine.py | 251 | 221 | 0 | 12%
src/dataknobs_fsm/execution/async_stream.py | 116 | 90 | 0 | 22%
src/dataknobs_fsm/execution/base_engine.py | 87 | 66 | 41 | 24%
src/dataknobs_fsm/execution/batch.py | 203 | 159 | 0 | 22%
src/dataknobs_fsm/execution/common.py | 176 | 151 | 2 | 14%
src/dataknobs_fsm/execution/context.py | 187 | 133 | 0 | 29%
src/dataknobs_fsm/execution/engine.py | 368 | 322 | 0 | 12%
src/dataknobs_fsm/execution/history.py | 286 | 240 | 0 | 16%
src/dataknobs_fsm/execution/network.py | 189 | 171 | 0 | 10%
src/dataknobs_fsm/execution/stream.py | 141 | 105 | 0 | 26%
src/dataknobs_fsm/functions/base.py | 143 | 67 | 139 | 53%
src/dataknobs_fsm/functions/library/database.py | 164 | 164 | 0 | 0%
src/dataknobs_fsm/functions/library/streaming.py | 277 | 277 | 0 | 0%
src/dataknobs_fsm/functions/library/transformers.py | 274 | 274 | 0 | 0%
src/dataknobs_fsm/functions/library/validators.py | 225 | 225 | 0 | 0%
src/dataknobs_fsm/functions/manager.py | 257 | 202 | 6 | 21%
src/dataknobs_fsm/io/adapters.py | 483 | 483 | 0 | 0%
src/dataknobs_fsm/io/base.py | 74 | 74 | 72 | 0%
src/dataknobs_fsm/io/utils.py | 139 | 139 | 0 | 0%
src/dataknobs_fsm/patterns/api_orchestration.py | 281 | 281 | 0 | 0%
src/dataknobs_fsm/patterns/error_recovery.py | 395 | 395 | 0 | 0%
src/dataknobs_fsm/patterns/etl.py | 197 | 197 | 0 | 0%
src/dataknobs_fsm/patterns/file_processing.py | 306 | 306 | 0 | 0%
src/dataknobs_fsm/resources/base.py | 119 | 61 | 19 | 49%
src/dataknobs_fsm/resources/database.py | 123 | 123 | 0 | 0%
src/dataknobs_fsm/resources/filesystem.py | 151 | 151 | 0 | 0%
src/dataknobs_fsm/resources/http.py | 176 | 176 | 0 | 0%
src/dataknobs_fsm/resources/manager.py | 274 | 238 | 0 | 13%
src/dataknobs_fsm/resources/pool.py | 166 | 130 | 0 | 22%
src/dataknobs_fsm/resources/properties.py | 113 | 113 | 7 | 0%
src/dataknobs_fsm/storage/base.py | 78 | 46 | 130 | 41%
src/dataknobs_fsm/storage/database.py | 177 | 153 | 2 | 14%
src/dataknobs_fsm/storage/file.py | 14 | 9 | 0 | 36%
src/dataknobs_fsm/storage/memory.py | 23 | 16 | 0 | 30%
src/dataknobs_fsm/streaming/core.py | 366 | 279 | 0 | 24%
src/dataknobs_fsm/streaming/db_stream.py | 203 | 178 | 0 | 12%
src/dataknobs_fsm/streaming/file_stream.py | 281 | 239 | 0 | 15%
Total | 11096 | 9431 | 510 | 15%

No items found using the specified filter.